@@ -1,9 +1,9 @@
 /*
  * ansilove.c
- * Ansilove 4.1.6
+ * Ansilove 4.2.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2022 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2023 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause license.
@@ -53,7 +53,7 @@ static void
 version(void)
 {
 	fprintf(stdout, "AnsiLove/C %s - ANSI / ASCII art to PNG converter\n"
-	    "Copyright (c) 2011-2022 Stefan Vogt, Brian Cassidy, and "
+	    "Copyright (c) 2011-2023 Stefan Vogt, Brian Cassidy, and "
 	    "Frederic Cambus.\n", VERSION);
 }
 
@@ -454,7 +454,7 @@ main(int argc, char *argv[])
 
 	timespecsub(&end, &begin, &elapsed);
 
-	fprintf(messages, "\nProcessed in %f seconds.\n",
+	fprintf(stderr, "Processed in %f seconds.\n",
 	    elapsed.tv_sec + elapsed.tv_nsec / 1E9);
 
 	ansilove_clean(&ctx);
