@@ -1,9 +1,9 @@
 /*
  * fonts.h
- * Ansilove 4.1.6
+ * Ansilove 4.2.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2022 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2023 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause license.
@@ -44,6 +44,7 @@ char *fonts[] = {
 	"nordic",
 	"russian",
 	"greek-869",
+	"spleen",
 	"terminus",
 	"amiga",
 	"microknight",
@@ -85,6 +86,7 @@ int fontsId[] = {
 	ANSILOVE_FONT_CP865,			/* Nordic */
 	ANSILOVE_FONT_CP866,			/* Russian */
 	ANSILOVE_FONT_CP869,			/* Greek */
+	ANSILOVE_FONT_SPLEEN,
 	ANSILOVE_FONT_TERMINUS,
 	ANSILOVE_FONT_TOPAZ,			/* Alias: amiga */
 	ANSILOVE_FONT_MICROKNIGHT,
